@@ -1,18 +1,18 @@
-### plotBrier.R --- 
+### plotBrier.R ---
 #----------------------------------------------------------------------
 ## author: Thomas Alexander Gerds
-## created: Feb 23 2017 (11:07) 
-## Version: 
-## last-updated: Mar  9 2022 (15:49) 
+## created: Feb 23 2017 (11:07)
+## Version:
+## last-updated: May 31 2022 (11:43) 
 ##           By: Thomas Alexander Gerds
-##     Update #: 74
+##     Update #: 75
 #----------------------------------------------------------------------
-## 
-### Commentary: 
-## 
+##
+### Commentary:
+##
 ### Change Log:
 #----------------------------------------------------------------------
-## 
+##
 ### Code:
 ##' Plot Brier score curves
 ##' @title Plot Brier curve
@@ -40,7 +40,7 @@
 ##' # survival
 ##' library(survival)
 ##' library(prodlim)
-##' set.seed(10)
+##' set.seed(7)
 ##' ds1=sampleData(40,outcome="survival")
 ##' ds2=sampleData(40,outcome="survival")
 ##' f1 <- coxph(Surv(time,event)~X1+X3+X5+X7+X9,data=ds1,x=TRUE)
@@ -49,7 +49,7 @@
 ##' plotBrier(xscore)
 #' @export
 #'
-#' 
+#'
 plotBrier <- function(x,
                       models,
                       which="score",
@@ -165,35 +165,44 @@ plotBrier <- function(x,
                                      forced=list("plot"=list(axes=FALSE),
                                                  "axis1"=list(side=1)),
                                      verbose=TRUE)
-                                     
+    
+                                     do.call("plot",control$plot)
                                      if (which%in%c("score","ipa")){
                                          ## Brier
-                                         do.call("plot",control$plot)
-                                         pframe[,{thisline <- control$line
-                                             thisline$col=thisline$col[[as.character(model[1])]]
-                                             thisline$lwd=thisline$lwd[[as.character(model[1])]]
-                                             thisline$lty=thisline$lty[[as.character(model[1])]]
-                                             thisline$pch=thisline$pch[[as.character(model[1])]]
-                                             thisline$type=thisline$type[[as.character(model[1])]]
-                                             thisline$x=times
-                                             if (which =="ipa"){
-                                                 thisline$y=IPA
-                                             }else{
-                                                 thisline$y=Brier
-                                             }
-                                             do.call("lines",thisline)},by=model]
-                                     }else{
-                                         ## delta Brier
-                                         do.call("plot",control$plot)
-                                         pframe[,{thisline <- control$line;
-                                             thisline$col=thisline$col[[as.character(contrast[1])]];
-                                             thisline$lwd=thisline$lwd[[as.character(contrast[1])]];
-                                             thisline$lty=thisline$lty[[as.character(contrast[1])]];
-                                             thisline$pch=thisline$pch[[as.character(contrast[1])]];
-                                             thisline$type=thisline$type[[as.character(contrast[1])]];
-                                             thisline$x=times;
-                                             thisline$y=delta.Brier;
-                                             do.call("lines",thisline)},by=contrast]
+                                         # not a very nice solution but this fixes the problem with the plot
+                                         model.list <- unique(pframe[["model"]])
+                                         times <- unique(pframe[["times"]])
+                                         for (mod in model.list){
+                                           thisline <- control$line
+                                           thisline$col=thisline$col[[as.character(mod)]]
+                                           thisline$lwd=thisline$lwd[[as.character(mod)]]
+                                           thisline$lty=thisline$lty[[as.character(mod)]]
+                                           thisline$pch=thisline$pch[[as.character(mod)]]
+                                           thisline$type=thisline$type[[as.character(mod)]]
+                                           thisline$x=times
+                                           if (which =="ipa"){
+                                             thisline$y=pframe[model==mod][["IPA"]] ## does this work?
+                                           }else{
+                                             thisline$y=pframe[model==mod][["Brier"]]
+                                           }
+                                           do.call("lines",thisline)}
+                                         }
+                                     else{
+                                       ## delta Brier
+                                       # not a very nice solution but this fixes the problem with the plot
+                                       contrast.list <- unique(pframe[["contrast"]])
+                                       times <- unique(pframe[["times"]])
+                                       for (con in contrast.list){
+                                         thisline <- control$line
+                                         thisline$col=thisline$col[[as.character(con)]]
+                                         thisline$lwd=thisline$lwd[[as.character(con)]]
+                                         thisline$lty=thisline$lty[[as.character(con)]]
+                                         thisline$pch=thisline$pch[[as.character(con)]]
+                                         thisline$type=thisline$type[[as.character(con)]]
+                                         thisline$x=times
+                                         thisline$y=pframe[contrast==con][["delta.Brier"]]
+                                         do.call("lines",thisline)
+                                       }
                                      }
                                      ## legend
                                      if (!(is.logical(legend[[1]]) && legend[[1]]==FALSE)){
