@@ -3,9 +3,9 @@
 ## author: Brice Ozenne
 ## created: sep  4 2017 (10:38) 
 ## Version: 
-## last-updated: Sep 17 2022 (06:57) 
-##           By: Thomas Alexander Gerds
-##     Update #: 175
+## last-updated: mar  7 2023 (18:31) 
+##           By: Brice Ozenne
+##     Update #: 177
 #----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -275,8 +275,11 @@ test_that("[confint.predictCox] compare to known values (1 fixed time, log log t
                      "survival.lowerBand" = c(0.05368, 0.00022), 
                      "survival.upperBand" = c(0.39115, 0.13183))
     ## butils::object2script(as.data.table(predRR1.loglog)[6:7,names(GS),with=FALSE], digit = 5)
-    expect_equal(ignore_attr=TRUE,as.data.table(predRR1.loglog)[6:7,names(GS),with=FALSE],
-                 GS, tolerance = 1e-4, scale = 1)
+    expect_equal(ignore_attr=TRUE,
+                 as.data.table(predRR1.loglog)[6:7,names(GS),with=FALSE],
+                 GS,
+                 tolerance = 1e-4,
+                 scale = 1)
 })
 
 ## ** At event times
@@ -1370,5 +1373,20 @@ test_that("iidCox - stopped early", {
     expect_equal(ignore_attr=TRUE,GS$survival.average.iid,test2$survival.average.iid)
 })
 
+## ** predictCox with interacitons
+test_that("predictCox - : operator", {
+    n <- 500
+    set.seed(10)
+    dt <- sampleData(n, outcome="survival")
+
+    m.cox <-  coxph(Surv(time,event)~ X1*X6+strata(X2),data=dt, x = TRUE, y = TRUE)
+    test <- predictCox(m.cox, newdata = dt[1], times = 5:8, average.iid = TRUE)
+
+    m2.cox <-  coxph(Surv(time,event)~ X1:X6+strata(X2),data=dt, x = TRUE, y = TRUE)
+    test2 <- predictCox(m2.cox, newdata = dt[1], times = 5:8, average.iid = TRUE) ## previously an error because of missing main term
+    expect_equal(as.double(test2$survival),c(0.5786438,0.5475801,0.4452037,0.3406072), tol = 1e-6)
+
+})
+
 #----------------------------------------------------------------------
 ### test-predictCox.R ends here
